<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.6.1 for parent theme Theatre WP for publication on ThemeForest
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */

require_once get_template_directory() . '/vendor/tgmpa/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'theatre_wp_register_required_plugins' );

/**
 * Register the required plugins for this theme.
 *
 * In this example, we register five plugins:
 * - one included with the TGMPA library
 * - two from an external source, one from an arbitrary source, one from a GitHub repository
 * - two from the .org repo, where one demonstrates the use of the `is_callable` argument
 *
 * The variables passed to the `tgmpa()` function should be:
 * - an array of plugin arrays;
 * - optionally a configuration array.
 * If you are not changing anything in the configuration array, you can remove the array and remove the
 * variable from the function call: `tgmpa( $plugins );`.
 * In that case, the TGMPA default settings will be used.
 *
 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
 */
function theatre_wp_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */

	$version_path = 'S5ABMLTzykEWMLCh';

	$plugins = array(

    array(
           'name' 					=> esc_html__( 'WPBakery Visual Composer', 'theatre-wp' ),
           'slug' 					=> 'js_composer',
           'source' 				=> get_template_directory() ."/vendor/js_composer.zip",
           'required' 			=> true,
           'version' 				=> '5.5.4',
           'force_activation' 		=> false,
           'force_deactivation' 	=> false,
           'external_url' 			=> '',
       ),
       array(
           'name' 					=> esc_html__( 'Revolution Slider', 'theatre-wp' ),
           'slug' 					=> 'revslider',
           'source' 				=> get_template_directory() ."/vendor/revslider.zip",
           'required' 			=> true,
           'version' 				=> '5.4.8',
           'force_activation' 		=> false,
           'force_deactivation' 	=> false,
           'external_url' 			=> '',
       ),
			 array(
           'name' 					=> esc_html__( 'Events Schedule WP Plugin', 'theatre-wp' ),
           'slug' 					=> 'weekly-class',
           'source' 				=> get_template_directory() ."/vendor/weekly-class.zip",
           'required' 			=> true,
           'version' 				=> '2.5.4',
           'force_activation' 		=> false,
           'force_deactivation' 	=> false,
           'external_url' 			=> '',
       ),
			 array(
           'name' 					=> esc_html__( 'xtender', 'theatre-wp' ),
           'slug' 					=> 'xtender',
           'source' 				=> get_template_directory() ."/vendor/xtender.zip",
           'required' 			=> true,
           'version' 				=> '1.4.8',
           'force_activation' 		=> false,
           'force_deactivation' 	=> false,
           'external_url' 			=> '',
       ),
			 array(
           'name' 					=> esc_html__( 'Ninja Forms', 'theatre-wp' ),
           'slug' 					=> 'ninja-forms',
           'required' 			=> false
       ),
			 array(
           'name' 					=> esc_html__( 'SVG Support', 'theatre-wp' ),
           'slug' 					=> 'svg-support',
           'required' 			=> false
       ),

	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'theatre-wp',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.


		'strings'      => array(
			'page_title'                      => esc_html__( 'Install Required Plugins', 'theatre-wp' ),
			'menu_title'                      => esc_html__( 'Install Plugins', 'theatre-wp' ),
			'installing'                      => esc_html__( 'Installing Plugin: %s', 'theatre-wp' ),
			'updating'                        => esc_html__( 'Updating Plugin: %s', 'theatre-wp' ),
			'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'theatre-wp' ),
			'notice_can_install_required'     => _n_noop(
				'This theme requires the following plugin: %1$s.',
				'This theme requires the following plugins: %1$s.',
				'theatre-wp'
			),
			'notice_can_install_recommended'  => _n_noop(
				'This theme recommends the following plugin: %1$s.',
				'This theme recommends the following plugins: %1$s.',
				'theatre-wp'
			),
			'notice_ask_to_update'            => _n_noop(
				'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.',
				'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.',
				'theatre-wp'
			),
			'notice_ask_to_update_maybe'      => _n_noop(

				'There is an update available for: %1$s.',
				'There are updates available for the following plugins: %1$s.',
				'theatre-wp'
			),
			'notice_can_activate_required'    => _n_noop(
				'The following required plugin is currently inactive: %1$s.',
				'The following required plugins are currently inactive: %1$s.',
				'theatre-wp'
			),
			'notice_can_activate_recommended' => _n_noop(
				'The following recommended plugin is currently inactive: %1$s.',
				'The following recommended plugins are currently inactive: %1$s.',
				'theatre-wp'
			),
			'install_link'                    => _n_noop(
				'Begin installing plugin',
				'Begin installing plugins',
				'theatre-wp'
			),
			'update_link' 					  => _n_noop(
				'Begin updating plugin',
				'Begin updating plugins',
				'theatre-wp'
			),
			'activate_link'                   => _n_noop(
				'Begin activating plugin',
				'Begin activating plugins',
				'theatre-wp'
			),
			'return'                          => esc_html__( 'Return to Required Plugins Installer', 'theatre-wp' ),
			'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'theatre-wp' ),
			'activated_successfully'          => esc_html__( 'The following plugin was activated successfully:', 'theatre-wp' ),
			'plugin_already_active'           => esc_html__( 'No action taken. Plugin %1$s was already active.', 'theatre-wp' ),
			'plugin_needs_higher_version'     => esc_html__( 'Plugin not activated. A higher version of %s is needed for this theme. Please update the plugin.', 'theatre-wp' ),
			'complete'                        => esc_html__( 'All plugins installed and activated successfully. %1$s', 'theatre-wp' ),
			'dismiss'                         => esc_html__( 'Dismiss this notice', 'theatre-wp' ),
			'notice_cannot_install_activate'  => esc_html__( 'There are one or more required or recommended plugins to install, update or activate.', 'theatre-wp' ),
			'contact_admin'                   => esc_html__( 'Please contact the administrator of this site for help.', 'theatre-wp' ),
			'nag_type'                        => '', // Determines admin notice type - can only be one of the typical WP notice classes, such as 'updated', 'update-nag', 'notice-warning', 'notice-info' or 'error'. Some of which may not work as expected in older WP versions.
		),

	);

	tgmpa( $plugins, $config );
}
