<?php

//define( 'THEATRE_WP_CACHE', true );

/** Set Content Width */
if ( ! isset( $content_width ) ) {
	$content_width = 660;
}

/** WP Actions */
add_action( 'wp_enqueue_scripts', 'theatre_wp_register_assets'  );
add_action( 'after_setup_theme', 'theatre_wp_menu_setup' );
add_action( 'after_setup_theme', 'theatre_wp_theme_support' );
add_action( 'after_setup_theme', 'theatre_wp_theme_localization'  );
add_action( 'widgets_init', 'theatre_wp_sidebars' );
add_action( 'init', 'theatre_wp_add_excerpts_to_pages' );
add_action( 'admin_init', 'theatre_wp_add_editor_styles' );

/** WP Filters */
add_filter( 'excerpt_length', 'theatre_wp_excerpt_length', 999 );
add_filter( 'the_content_more_link', 'theatre_wp_modify_read_more_link' );

/** Curly Actions */
add_action( 'theatre_wp_after_post_content', 'theatre_wp_get_sharing'  );
add_action( 'theatre_wp_toolbar', 'theatre_wp_get_toolbar_text'  );
add_action( 'theatre_wp_toolbar', array( 'TheatreWpWPML', 'get_wpml_selector' )  );

function theatre_wp_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}


function theatre_wp_add_excerpts_to_pages() {
	add_post_type_support( 'page', 'excerpt' );
}

function theatre_wp_modify_read_more_link() {
	return "<a href='" . get_the_permalink() . "' title='" . get_the_title() . "' class='btn btn-sm btn-link more-link'>" . esc_html__( 'Read More', 'theatre-wp' ) . "</a>";
}


function theatre_wp_get_toolbar_text(){

	if( function_exists('icl_get_languages') && ! wp_validate_boolean( esc_attr( get_theme_mod( 'wpml' ) ) ) )
		return;

    $toolbar_text = wp_kses_post( get_theme_mod( 'toolbar' ) );

	if( ! empty( $toolbar_text ) )
		echo do_shortcode( $toolbar_text );
}

function theatre_wp_get_sharing(){

    if( ! TheatreWpHelpers::has_sharing() )
      return;

    get_template_part( 'template-parts/sharing' );

  }

function theatre_wp_theme_localization(){
	  load_theme_textdomain( 'theatre-wp', get_template_directory() . '/languages');
}

function theatre_wp_excerpt_length() {

		$length	= esc_attr( get_theme_mod( 'excerpt' ) );

		if ( ! $length )
			$length = 60;

		return $length;

	}

function theatre_wp_register_assets(){

	wp_register_script(
    'theatre_wp_waypoints',
    get_template_directory_uri() . '/dev/libs/waypoints/jquery.waypoints.min.js',
    array( 'jquery' ),
    wp_validate_boolean( WP_DEBUG ) ? rand() : null,
    true
  );

	wp_register_script(
    'theatre_wp_waypoints_sticky',
    get_template_directory_uri() . '/dev/libs/waypoints/sticky.min.js',
    array( 'jquery', 'theatre_wp_waypoints' ),
    wp_validate_boolean( WP_DEBUG ) ? rand() : null,
    true
  );

	wp_register_script(
    'theatre_wp_imagefill',
    get_template_directory_uri() . '/dev/libs/imagefill/jquery-imagefill.js',
    array( 'jquery' ),
    wp_validate_boolean( WP_DEBUG ) ? rand() : null,
    true
  );

	wp_register_script(
    'theatre_wp_magnific',
    get_template_directory_uri() . '/dev/libs/magnific/jquery.magnific-popup.min.js',
    array( 'jquery' ),
    wp_validate_boolean( WP_DEBUG ) ? rand() : null,
    true
  );

	wp_register_script(
    'theatre_wp_owl',
    get_template_directory_uri() . '/dev/libs/owl-carousel/owl.carousel.min.js',
    array( 'jquery' ),
    wp_validate_boolean( WP_DEBUG ) ? rand() : null,
    true
  );


  wp_enqueue_script(
    'theatre_wp-scripts',
    get_template_directory_uri() . '/assets/front/js/scripts-min.js',
    array( 'jquery', 'jquery-masonry', 'theatre_wp_waypoints', 'theatre_wp_waypoints_sticky', 'theatre_wp_imagefill', 'theatre_wp_magnific', 'theatre_wp_owl' ),
    wp_validate_boolean( WP_DEBUG ) ? rand() : null,
    true
  );

	wp_localize_script( 'theatre_wp-scripts', 'theatre_wp_theme_data', array(
		'menu' => array(
			'sticky' => wp_validate_boolean( esc_attr( get_theme_mod( 'navigation_sticky' ) ) )
		)
	));

	if ( is_singular() )
		wp_enqueue_script( "comment-reply" );

  wp_enqueue_style(
    'theatre_wp-style',
    get_stylesheet_uri(),
    null,
    wp_validate_boolean( WP_DEBUG ) ? rand() : '1.1.2',
    'all'
  );

}

function theatre_wp_menu_setup(){
  register_nav_menu( 'main_navigation',  esc_html__( 'Main Navigation', 'theatre-wp' ) );
	register_nav_menu( 'footer_navigation',  esc_html__( 'Footer Navigation', 'theatre-wp' ) );
}



function theatre_wp_sidebars(){
	if ( function_exists( 'register_sidebar' ) )
		register_sidebar( array(
		'name'			 		 => esc_html__( 'Blog Widgets Area', 'theatre-wp' ),
		'description' 	 => esc_html__( 'This sidebar is visible on the right side of the screen, on all blog pages of your website.', 'theatre-wp' ),
		'id'			 	 		 => 'sidebar_blog',
		'before_widget'	 => '<aside id="%1$s" class="sidebar-widget %2$s animated">',
		'after_widget' 	 => '</aside>',
		'before_title'	 => '<h4 class="widget-title color-primary">',
		'after_title'	 	 => '</h4>',
	) );

	if ( function_exists( 'register_sidebar' ) )
		register_sidebar( array(
		'name'			 		 => esc_html__( 'Pages Widget Area' , 'theatre-wp' ),
		'description' 	 => esc_html__( 'This sidebar is visible on the left or right side of the screen, on pages which use a page template with sidebar.', 'theatre-wp' ),
		'id'			 			 => 'sidebar_page',
		'before_widget'	 => '<aside id="%1$s" class="sidebar-widget %2$s">',
		'after_widget' 	 => '</aside>',
		'before_title'	 => '<h4 class="widget-title color-primary">',
		'after_title'	 	 => '</h4>',
	));

	if ( function_exists( 'register_sidebar' ) )
		register_sidebar( array(
		'name'			 		 => esc_html__( 'Footer Widget Area' , 'theatre-wp' ),
		'description' 	 => esc_html__( 'This sidebar is visible on all pages of your website, in the footer area.', 'theatre-wp' ),
		'id'			 			 => 'footer_widget_area',
		'before_widget'	 => '<aside id="%1$s" class="col-sm-3 sidebar-widget %2$s">',
		'after_widget' 	 => '</aside>',
		'before_title'	 => '<h5 class="widget-title color-primary">',
		'after_title'	 	 => '</h5>',
	));

}


function theatre_wp_theme_support(){
	add_theme_support( 'title-tag' );
	add_theme_support( 'post-thumbnails', array( 'post', 'page' ) );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'custom-background' );
	add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'chat', 'link', 'image', 'quote', 'status', 'video', 'audio') );
	add_theme_support( 'custom-header', array(
		'random-default'		=> true,
		'width'             => 1920,
		'height'            => 1080,
		'flex-height'       => true,
		'flex-width'        => true,
		'header-text'       => true,
		'uploads'           => true
	) );
}

/*	Theme Update */
$theatre_wp_tf_user = esc_attr( get_theme_mod( 'tf_user' ) );
$theatre_wp_tf_api  = esc_attr( get_theme_mod( 'tf_api' ) );

if ( ! empty( $theatre_wp_tf_user ) && ! empty( $theatre_wp_tf_api ) ) {

	require_once( trailingslashit( get_template_directory() ) . 'framework/theme-update/envato-wp-theme-updater.php' );

	if( class_exists( 'Envato_WP_Theme_Updater' ) )
		Envato_WP_Theme_Updater::init( $theatre_wp_tf_user, $theatre_wp_tf_api, 'Curly Themes' );

}

/* Framework */
require_once( trailingslashit( get_template_directory() ) . 'framework/class.helpers.php' );
require_once( trailingslashit( get_template_directory() ) . 'framework/class.customizer.php' );
require_once( trailingslashit( get_template_directory() ) . 'framework/class.typography.php' );
require_once( trailingslashit( get_template_directory() ) . 'framework/class.color.php' );
require_once( trailingslashit( get_template_directory() ) . 'framework/class.heading.php' );
require_once( trailingslashit( get_template_directory() ) . 'framework/class.comments.php' );
require_once( trailingslashit( get_template_directory() ) . 'framework/class.vc.extend.php' );
require_once( trailingslashit( get_template_directory() ) . 'framework/class.woo.php' );
require_once( trailingslashit( get_template_directory() ) . 'framework/class.wpml.php' );
require_once( trailingslashit( get_template_directory() ) . 'framework/class.plugins.php' );

/* Defaults */
require_once( trailingslashit( get_template_directory() ) . 'defaults/mods.php' );
require_once( trailingslashit( get_template_directory() ) . 'defaults/ips.php' );
require_once( trailingslashit( get_template_directory() ) . 'defaults/renders.php' );

add_filter( 'wcs_view_css', 'theatre_wp_view_css_masonry_grid', 100, 3 );

add_filter( 'wcs_views', 'theatre_wp_views', 100 );

function theatre_wp_views( $views ){
	foreach( $views as $key => $view ){
		if( $view['value'] === 12 ){
			$views[$key]['prepend_filters'] = false;
		}
	}
	return $views;
}

function theatre_wp_view_css_masonry_grid( $css, $data, $schedule_id ){

  if(  ! isset( $data['view'] ) || intval( $data['view'] ) !== 7 )
    return $css;

  /** Basic */
  $color_special = isset( $data['color_special'] ) && ! empty( $data['color_special'] ) ? $data['color_special'] : '#BF392B';
  $color_grid_item_bg = isset( $data['color_grid_item_bg'] ) && ! empty( $data['color_grid_item_bg'] ) ? $data['color_grid_item_bg'] : '#ffffff';
  $grid_items_lg = isset( $data['grid_items_lg'] ) ? $data['grid_items_lg'] : 4;
  $grid_items_md = isset( $data['grid_items_md'] ) ? $data['grid_items_md'] : 3;
  $grid_items_xs = isset( $data['grid_items_xs'] ) ? $data['grid_items_xs'] : 1;
  $gutter_lg = ( 6 * ( $grid_items_lg - 1 ) ) / $grid_items_lg;
  $gutter_md = ( 6 * ( $grid_items_md - 1 ) ) / $grid_items_md;
  $gutter_xs = ( 6 * ( $grid_items_xs - 1 ) ) / $grid_items_xs;
  $item_width_lg = ( 100 / $grid_items_lg ) - $gutter_lg;
  $item_width_md = ( 100 / $grid_items_md ) - $gutter_md;
  $item_width_xs = ( 100 / $grid_items_xs ) - $gutter_xs;
  $item_width_lg_active = ( 6 * $item_width_lg ) + 6 > 100 ? 100 : ( 6 * $item_width_lg ) + 6;
  $item_width_md_active = ( 6 * $item_width_md ) + 6 > 100 ? 100 : ( 6 * $item_width_md ) + 6;
  $item_width_xs_active = ( 6 * $item_width_xs ) + 6 > 100 ? 100 : ( 6 * $item_width_xs ) + 6;
  $css .= "
    .wcs-timetable--$schedule_id .wcs-timetable__grid .ti-time,
    .wcs-timetable--$schedule_id .wcs-timetable__grid .wcs-class__title{
      color: $color_special;
    }
    .wcs-timetable--$schedule_id .wcs-timetable__grid .wcs-class{
      background-color: $color_grid_item_bg;
    }
    .wcs-class__minimize{
      background-color: " . CurlyWeeklyClassShortcodes::hex2rgb( $color_grid_item_bg, 0.85 ) . ";
    }
    .wcs-timetable--$schedule_id .wcs-isotope-item,
    .wcs-timetable--$schedule_id .wcs-class{
      width: {$item_width_xs}%;
    }
    .wcs-timetable--$schedule_id .wcs-class--active{
      width: {$item_width_xs_active}%;
    }
    @media (min-width: 600px) {
      .wcs-timetable--$schedule_id .wcs-isotope-item,
      .wcs-timetable--$schedule_id .wcs-class{
        width: {$item_width_md}%;
      }
      .wcs-timetable--$schedule_id .wcs-class--active{
        width: {$item_width_md_active}%;
      }
    }
    @media (min-width: 1000px) {
      .wcs-timetable--$schedule_id .wcs-isotope-item,
      .wcs-timetable--$schedule_id .wcs-class{
        width: {$item_width_lg}%;
      }
      .wcs-timetable--$schedule_id .wcs-class--active{
        width: {$item_width_lg_active}%;
      }
    }
  ";

  return $css;
}

add_filter( 'wcs_post_type_labels', 'theatre_wp_def_type_labels' );
function theatre_wp_def_type_labels( $labels ){
  $labels = array(
    'name'               => _x( 'Events', 'post type general name', 'theatre-wp' ),
    'singular_name'      => _x( 'Events', 'post type singular name', 'theatre-wp' ),
    'menu_name'          => _x( 'Events', 'admin menu', 'theatre-wp' ),
    'name_admin_bar'     => _x( 'Events', 'add new on admin bar', 'theatre-wp' ),
    'add_new'            => _x( 'Add New', 'class', 'theatre-wp' ),
    'add_new_item'       => __( 'Add New Events', 'theatre-wp' ),
    'new_item'           => __( 'New Events', 'theatre-wp' ),
    'edit_item'          => __( 'Edit Events', 'theatre-wp' ),
    'view_item'          => __( 'View Events', 'theatre-wp' ),
    'all_items'          => __( 'All Events', 'theatre-wp' ),
    'search_items'       => __( 'Search Events', 'theatre-wp' ),
    'parent_item_colon'  => __( 'Parent Events:', 'theatre-wp' ),
    'not_found'          => __( 'No events found.', 'theatre-wp' ),
    'not_found_in_trash' => __( 'No events found in Trash.', 'theatre-wp' )
  );
  return $labels;
}

add_filter( 'wcs_tax_labels', 'theatre_wp_def_taxes', 10, 2 );

function theatre_wp_def_taxes( $labels, $tax ){

  if( $tax === 'wcs-type' ){
    $labels = array(
			'name'              => _x( 'Event Types', 'taxonomy general name', 'theatre-wp' ),
			'singular_name'     => _x( 'Event Type', 'taxonomy singular name', 'theatre-wp' ),
			'search_items'      => __( 'Search Event Types', 'theatre-wp' ),
			'all_items'         => __( 'All Event Types', 'theatre-wp' ),
			'parent_item'       => __( 'Parent Event', 'theatre-wp' ),
			'parent_item_colon' => __( 'Parent Event:', 'theatre-wp' ),
			'edit_item'         => __( 'Edit Event', 'theatre-wp' ),
			'update_item'       => __( 'Update Event', 'theatre-wp' ),
			'add_new_item'      => __( 'Add New Event Type', 'theatre-wp' ),
			'new_item_name'     => __( 'New Event Type', 'theatre-wp' ),
			'menu_name'         => __( 'Event Types', 'theatre-wp' )
		);
  }

  if( $tax === 'wcs-instructor' ){
    $labels = array(
			'name'                       => _x( 'Directors', 'taxonomy general name', 'theatre-wp' ),
			'singular_name'              => _x( 'Director', 'taxonomy singular name', 'theatre-wp' ),
			'search_items'               => __( 'Search  Directors', 'theatre-wp' ),
			'popular_items'              => __( 'Popular Directors', 'theatre-wp' ),
			'all_items'                  => __( 'All Directors', 'theatre-wp' ),
			'parent_item'                => null,
			'parent_item_colon'          => null,
			'edit_item'                  => __( 'Edit Director', 'theatre-wp' ),
			'update_item'                => __( 'Update Director', 'theatre-wp' ),
			'add_new_item'               => __( 'Add New Director', 'theatre-wp' ),
			'new_item_name'              => __( 'New Director Name', 'theatre-wp' ),
			'separate_items_with_commas' => __( 'Separate directors with commas', 'theatre-wp' ),
			'add_or_remove_items'        => __( 'Add or remove directors', 'theatre-wp' ),
			'choose_from_most_used'      => __( 'Choose from the most used directors', 'theatre-wp' ),
			'not_found'                  => __( 'No directors found.', 'theatre-wp' ),
			'menu_name'                  => __( 'Directors', 'theatre-wp' )
		);
  }

  return $labels;
}


?>
